@@ -6,4 +6,4 @@ class EmailFilter(Filter):
     '''
 
     def __init__(self):
-        super().__init__('text-davinci-002', 'marketing email for the company')
\ No newline at end of file
+        super().__init__('marketing email for the company')
\ No newline at end of file
