@@ -1,7 +1,6 @@
 from datetime import datetime
-import time
 from powerml.utils.run_ai import run_ai
-from powerml.utils.constants import PARALLEL_REQUEST_LIMIT, DELAY_IN_SECONDS
+from powerml.utils.constants import PARALLEL_REQUEST_LIMIT
 
 class Filter():
     '''
@@ -11,9 +10,9 @@ class Filter():
     # NOTE: Would like to add a general filter for near duplicates using Greg's Presto method
     general_filters = {}
 
-    def __init__(self, model, prompt):
-        self.model = model
+    def __init__(self, prompt, model='text-davinci-003'):
         self.prompt = prompt
+        self.model = model
         self.filters = dict(self.general_filters, Invalid=self.__filter_invalid)
 
     def __add_input(self, data):
@@ -39,7 +38,6 @@ class Filter():
                 is_valid = [is_valid]
             is_valid = [False if 'no' in output.strip().lower() else True for output in is_valid]
             valid_examples.extend([datum for j, datum in enumerate(curr_data) if is_valid[j]])
-            time.sleep(DELAY_IN_SECONDS)
         return valid_examples
 
     def __filter_invalid(self, data):
