@@ -7,5 +7,4 @@ class ForecastFilter(Filter):
     '''
 
     def __init__(self):
-        # TODO: figure out a prompt that works
-        super().__init__('text-davinci-002', 'daily revenue forecast for the podcast')
+        super().__init__('daily revenue forecast that does not include null values')
