@@ -6,4 +6,4 @@ class MenuFilter(Filter):
     '''
 
     def __init__(self):
-        super().__init__('text-davinci-002', 'order for the conversation')
\ No newline at end of file
+        super().__init__('order for the conversation')
\ No newline at end of file
