@@ -6,4 +6,4 @@ class QuestionFilter(Filter):
     '''
 
     def __init__(self):
-        super().__init__('text-davinci-002', 'question for students of the lesson')
\ No newline at end of file
+        super().__init__('question for students of the lesson')
\ No newline at end of file
