@@ -6,4 +6,4 @@ class SQLFilter(Filter):
     '''
 
     def __init__(self):
-        super().__init__('text-davinci-002', 'SQL query')
\ No newline at end of file
+        super().__init__('SQL query')
\ No newline at end of file
