@@ -11,9 +11,9 @@ class WriteEmailModel:
         self.model_name = "stensul/email-copy"
         self.temperature = temperature
 
-    def predict(self, input):
+    def predict(self, subject):
         output = self.model.predict(
-            input,
+            subject,
             max_tokens=self.max_output_tokens,
             temperature=self.temperature,
             model=self.model_name
