@@ -8,9 +8,18 @@ def get_config(dictionary={}):
 
 
 def setup_config(dictionary):
-    home = os.path.expanduser("~")
-    home_config_path = os.path.join(home, ".powerml/configure.yaml")
     return config.ConfigurationSet(
         config.config_from_dict(dictionary),
-        config.config_from_yaml(home_config_path, read_from_file=True),
+        home_yaml_config(),
     )
+
+
+def home_yaml_config():
+    home = os.path.expanduser("~")
+    home_config_path = os.path.join(home, ".powerml/configure.yaml")
+    if os.path.exists(home_config_path):
+        yaml_config = config.config_from_yaml(
+            home_config_path, read_from_file=True)
+    else:
+        yaml_config = config.config_from_dict({})
+    return yaml_config
