@@ -35,8 +35,6 @@ def run_ai(prompt="Say this is a test",
     if api == "powerml":
         # if the model is one of our models, then hit our api
         resp = powerml_completions(params, key)
-        if resp.status_code != 200:
-            raise Exception(resp.status_code)
         resp = resp.json()
         if 'error' in resp:
             raise Exception(str(resp))
@@ -47,8 +45,6 @@ def run_ai(prompt="Say this is a test",
     else:
         # otherwise hit openai
         resp = openai_completions(params, key)
-        if resp.status_code != 200:
-            raise Exception(resp.status_code)
         resp = resp.json()
         if 'error' in resp:
             raise Exception(str(resp))
@@ -73,11 +69,16 @@ def powerml_completions(params, key):
         url="https://api.staging.powerml.co/v1/completions",
         headers=headers,
         json=params)
+    if response.status_code != 200:
+        raise requests.exceptions.RequestException
     return response
 
 
 @sleep_and_retry
 @limits(calls=20, period=60)
+@backoff.on_exception(backoff.expo,
+                      requests.exceptions.RequestException,
+                      max_time=300)
 def openai_completions(params, key):
     headers = {
         "Authorization": "Bearer " + key,
@@ -86,6 +87,8 @@ def openai_completions(params, key):
         url="https://api.openai.com/v1/completions",
         headers=headers,
         json=params)
+    if response.status_code != 200:
+        raise requests.exceptions.RequestException
     return response
 
 
